C
C PURPOSE: FUNCTION NEEDED IN 6J CALCULATION
C
C INPUTS:
C
C OUTPUTS:
C
C COMMON:
C
C COMMENTS: OCTOBER 6, 1999, P. JUDGE
C 
	FUNCTION FN2(IJ1,IJ2,IJ3)
C   USED IN 6J CALCULATION
	INCLUDE 'PREC'
	INCLUDE 'PARAM'
	INCLUDE 'FACT'
	L1=(IJ1+IJ2-IJ3)/2
	L2=(IJ2+IJ3-IJ1)/2
	L3=(IJ3+IJ1-IJ2)/2
	L4=(IJ1+IJ2+IJ3)/2+1
	FN2=.5*(FL(L1)+FL(L2)+FL(L3)-FL(L4))

	RETURN
	END
