C
C PURPOSE: REWINDS FORTRAN UNIT LU
C
C INPUTS:
C
C OUTPUTS:
C
C COMMON:
C
C COMMENTS: OCTOBER 6, 1999, P. JUDGE
C 
      SUBROUTINE REWIND(LU)
      INCLUDE 'PREC'
      REWIND LU
C
      RETURN
      END
C
C***********************************************************************
C
