C
C PURPOSE: COMPUTE COLLISION RATES C(2) EQN (20) OF 
C          CASINI, R. & JUDGE, P. G., 1999. AP J 522, 524-539
C          A SUM OF SUPERELASTIC COLLISIONS IS MADE FOR LEVELS LOWER
C          THAN IJ, FOR THE CASE K=0 ONLY.  
C INPUTS:
C          IJ       INDEX OF LEVEL.  
C       
C OUTPUTS:
C          C2COEFF  
C COMMON:
C
C COMMENTS: OCTOBER 6, 1999, P. JUDGE
C 
	SUBROUTINE C2(IJ,C2COEFF)
C  THIS SUBROUTINE CALCULATES THE COLLISIONAL RATES C(2)
	INCLUDE 'PREC'
	C2COEFF=0.0
	IZ=0
	DO IJ1=1,IJ-1
	  C2COEFF=CS(IJ1,IJ,IZ)+C2COEFF
	END DO
	RETURN
	END
