C
C PURPOSE: RETURNS CLOCK TIME FROM CPU IN SECONDS
C
C INPUTS:
C
C OUTPUTS:
C
C COMMON:
C
C COMMENTS: OCTOBER 6, 1999, P. JUDGE
C 
      FUNCTION SECOND()
      INCLUDE 'PREC'
      REAL XXX(2),ETIME
      DUMMY=ETIME(XXX)
      SECOND=XXX(1)
      RETURN
      END
