C
C PURPOSE: FUNCTION NEEDED FOR 3J CALCULATION
C
C INPUTS:
C
C OUTPUTS:
C
C COMMON:
C
C COMMENTS: OCTOBER 6, 1999, P. JUDGE
C 
	FUNCTION FN1(RJ1,RJ2,RJ3,RM1,RM2,RM3)
C   USED IN 3J CALCULATION
	INCLUDE 'PREC'
	INCLUDE 'PARAM'
	INCLUDE 'CINTS'
	INCLUDE 'FACT'
C

	L1=NINT(RJ1+RJ2-RJ3)
	L2=NINT(RJ2+RJ3-RJ1)
	L3=NINT(RJ3+RJ1-RJ2)
	L4=NINT(RJ1+RJ2+RJ3+ONE)
	L5=NINT(RJ1+RM1)
	L6=NINT(RJ1-RM1)
	L7=NINT(RJ2+RM2)
	L8=NINT(RJ2-RM2)
	L9=NINT(RJ3+RM3)
	L10=NINT(RJ3-RM3)
	FN1=0.5*(FL(L1)+FL(L2)+FL(L3)-FL(L4)+FL(L5)+FL(L6)
     /	    +FL(L7)+FL(L8)+FL(L9)+FL(L10))
	RETURN
	END
