C
C PURPOSE: COMPUTE ELASTIC MULTIPOLAR COLLISIONAL RATE
C
C INPUTS:
C       IJ   LEVEL INDEX
C       K    MULTIPOLAR COMPONENT
C OUTPUTS:
C
C COMMON:
C
C RESTRICTIONS:  
C
C UPDATED:  18 JAN 2014 RC/PGJ. REMOVED THE INCORRECT CECOFF CODE.
C
C COMMENTS: OCTOBER 6, 1999, P. JUDGE
C 
C EDITED: JUNE 6 2019 P. JUDGE
C INTEGER DO-LOOP VARIABLES
C FIXED ERRONEOUS DENOMINATOR IN GAMMAS
C ---Sept 2022 replaced pre 6jul22 version
C	
	FUNCTION GAMMAE(IJ,K)
C
	INCLUDE 'PREC'
	INCLUDE 'PARAM'
	INCLUDE 'CSE'
	INCLUDE 'CLU'
	INCLUDE 'CATMOS'
	INCLUDE 'CATOM'
	INCLUDE 'CINPUT'
	INCLUDE 'CINTS'
C
	GAMMAE=ZERO
	IF(ICOLL .EQ. 0 .OR. ICOLLMM .EQ. 0) RETURN
C
C EQ BEFORE (A4.10B) OF LANDI'S BOOK:
C
	AA=AJ(IJ) 
	NJ=INT(AA)
	FK=FLOAT(K)
        DO N=-NJ,NJ
	   DO NP=-NJ,NJ
	      DO M=0,K,2
		 P=FLOAT(M)
		 F3=FUN3J(AA,AA,FK,-AN,ANP,P)
		 GAMMAE=GAMMAE + CMM(IJ,IJ,N,NP)*F3*F3
     *            *(TWO*FK+ONE)/(TWO*AA+ONE)
	     ENDDO
	  ENDDO
	ENDDO
	RETURN
	END
